function [xd,yd] = deriv(xdata,ydata,order)
%DERIV is the generic function to calculate first or second order
%derivative of the given data points. We have implemented here the
%three-point numerical method for both first and second order derivatives.
%Using the three-point method means we stand to lose three data points in
%the derivative dataset. Here we ignore the last three points in the input
%data.
%
%   Syntax:     [xd,yd] = deriv(xdata,ydata,order)
%
%   OUTPUTS:
%   'xd'        x-data points of the derivative
%   'yd'        y-data points of the derivative
%
%   INPUTS:
%   'xdata'     x-data points of the input data.
%   'ydata'     y-data points of the input data.
%   'order'     order of the derivative required. 
%               1 for calculating the first order derivative and 
%               2 for calculating the second order derivative.  
%
h = xdata(2) - xdata(1);
if order == 1
    for i = 1:(size(ydata)-3)
        yd(i) = (2*ydata(i+3)-9*ydata(i+2)+18*ydata(i+1)-11*ydata(i))/(6*h);
        xd(i) = xdata(i);
    end
elseif order == 2
    for i = 1:size(ydata)-3
        yd(i) = (-1*ydata(i+3)+4*ydata(i+2)-5*ydata(i+1)+2*ydata(i))/(h^2);
        xd(i) = xdata(i);
    end    
end

end
