function [d1i,d1f,d2f] = processdata(r1i,r1f,r2f)
%PROCESSDATA takes the three tracked position datasets as input and returns the
%linear displacement from the initial point separately for each dataset.
%
%   Syntax:     [d1i,d1f,d2f] = processdata(r1i,r1f,r2f);
%
%   OUTPUTS:
%   'd1i'         the displacement vector relative to first point.
%   'd1f'         the displacement vector relative to first point.
%   'd2f'         the displacement vector relative to first point.
%   
%   INPUTS:
%   'r1i'       the initial tracked data for puck 1. 
%   'r1f'       the final tracked data for puck 1.
%   'r2f'       the final tracked data for puck 2.
%               The tracked datasets should each be a two-column
%               matrix with x and y coordinates of the tracked positions.
%
for i = 1:size(r1i,1)
    d1i(i,1) = sqrt((r1i(i,1)-r1i(1,1))^2+(r1i(i,2)-r1i(1,2))^2);
    d1f(i,1) = sqrt((r1f(i,1)-r1f(1,1))^2+(r1f(i,2)-r1f(1,2))^2);
    d2f(i,1) = sqrt((r2f(i,1)-r2f(1,1))^2+(r2f(i,2)-r2f(1,2))^2);
end

end
