function [time, positionblue, positiongreen] = trackmob(filename,knownDistance)
%TRACKMOB reads a video file and returns the timestamps and tracked
%position coordinates. This special variation of this function tracks two
%different objects at the same time.
%
%   Syntax:     [time, position] = trackmob(filename,knownDistance);
%
%   OUTPUTS:
%   'time'          the timestamps corresponding to each frame.
%   'positionblue'  the tracked positions in x and y directions for the
%                   blue marker
%                   write positionblue(:,1) to get x coordinates
%                   write positionblue(:,2) to get y coordinates
%   'positiongreen' the tracked positions in x and y directions for the
%                   green marker
%                   write positiongreen(:,1) to get x coordinates
%                   write positiongreen(:,2) to get y coordinates
%
%   INPUTS:
%   'filename'      the filename of the video in the same folder as the function. 
%   'knownDistance' the range of frames to be supported. e.g. ''100:200'' if you 
%                   wish to process only from 100th frame until the 200th
%                   frame.
%
vidobj = VideoReader(filename);
framerate = 240;
arraygreen =[];
arrayblue = [];
imshow(read(vidobj,1));
[dx, dy] = ginput(2);
distPX = sqrt((dy(2)-dy(1))^2+(dx(2)-dx(1))^2);
scale = knownDistance/distPX;
close(gcf);
tic
for i=1:vidobj.NumberOfFrames
    frame= read(vidobj,i);
    r = frame(:, :, 1);
    g = frame(:, :, 2);
    b = frame(:, :, 3);

    justGreen = g - r/2 - b/2;
    justBlue = b - r/2 - g/2;

    bwgreen = justGreen>50;
    bwblue = justBlue>50;

    bwmarkergreen = bwareaopen(bwgreen, 100);
    bwmarkerblue = bwareaopen(bwblue,100);
    
    sgreen  = regionprops(bwmarkergreen, {'centroid'});
    sblue  = regionprops(bwmarkerblue, {'centroid'});
    
    if numel(sgreen)>0
        sgreen = sgreen.Centroid;
        sblue = sblue.Centroid;
        arraygreen(end+1,:) = sgreen;
        arrayblue(end+1,:) = sblue;
        hold off;imshow(frame);
        hold on;
        plot(sgreen(1),sgreen(2),'ob','markersize',10);
        plot(sblue(1),sblue(2),'og','markersize',10);
        pause(0.01);
    end
end
arrayblue(:,2) = 240 - arrayblue(:,2);
arraygreen(:,2) = 240 - arraygreen(:,2);
positionblue = arrayblue*scale;
positiongreen = arraygreen*scale;
close(gcf);
clc;toc
time = (0:(size(arrayblue,1)-1))'/framerate;
end
